[comment {-*- tcl -*- doctools manpage}]
[manpage_begin adbsql n 1.0]
[moddesc {Tcl SQL connectivity}]
[titledesc {MySQL connectivity for ADB Tcl database implementation}]
[copyright {Roalt Aalmoes, 2007}]
[require Tcl 8]
[require mysqltcl]
[description]
[keywords database tcl mysql mysqltcl sql adb]
[para]

This package provides connectivity of an ADB database to a MySQL
database. By using adbsql in combination with adb and a MySQL
database, your data is always safely stored in a database, even if you
did not save it to a file.

[para]

This package uses the mysqltcl package that should be installed.

[section COMMANDS]

[list_begin definitions]

[call [cmd ADBSQL::Connect] [opt "[option -port] [arg "portno"]"] [opt "[option -host] [arg "host"]"] [opt "[option -user] [arg "username"]"] [opt "[option -password] [arg "password"]"] [opt "[option -database] [arg "database"]"] [opt "[option -new] [arg "YesOrNo"]"] ]

Connect and make use of a MySQL database, instead of storing the records internally. When this call is successful, all calls to ADB functions that modify the database are automatically passed on to calls to change this MySQL database.

[nl]

This function returns TRUE (1) if succesfull or FALSE (0) if an error
occurred. In case of an error, use [cmd ADBSQL::ErrorMessage] to get
the error message string.

[nl]
[emph Example:]
[example_begin]
    set result [lb]DBSQL::Connect \
                    -port 3306 \
                    -host 127.0.0.1 \
                    -user myuser \
                    -password topsecret \
                    -database adbexample \
                    -new 1[rb]
    if { $result == 0 } {
        tk_dialog .hi "Error" \
	    "Cannot open database. Error message: [lb]DBSQL::ErrorMessage[rb]" \
	    error {} Ok
        return
    }

[example_end]

[call [cmd ADBSQL::Disconnect] ]

Disconnect from a previously connected database. After a disconnect, the internal database of ADB itself is used again. Note that this internal database is [emph Not] automatically filled!

[call [cmd ADBSQL::ErrorMessage] ]

Return the last known error string. This function can be called if one of the other functions returns a FALSE (0) value.

[call [cmd ADBSQL::InUse] ]

This function returns if the MySQL database is used. The return value is a boolean and TRUE or 1 indicates that a MySQL database is indeed used.

[list_end]
[manpage_end]
